==> kubernetes-model-kustomize-6.6.2-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/LegacySortOptionsFluentImpl.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import java.lang.SuppressWarnings;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LegacySortOptionsFluentImpl<A extends LegacySortOptionsFluent<A>> extends BaseFluent<A> implements LegacySortOptionsFluent<A>{
  public LegacySortOptionsFluentImpl() {
  }
  public LegacySortOptionsFluentImpl(LegacySortOptions instance) {
    this.withOrderFirst(instance.getOrderFirst()); 
    this.withOrderLast(instance.getOrderLast()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private List<String> orderFirst = new ArrayList<String>();
  private List<String> orderLast = new ArrayList<String>();
  private Map<String,Object> additionalProperties;
  public A addToOrderFirst(Integer index,String item) {
    if (this.orderFirst == null) {this.orderFirst = new ArrayList<String>();}
    this.orderFirst.add(index, item);
    return (A)this;
  }
  public A setToOrderFirst(Integer index,String item) {
    if (this.orderFirst == null) {this.orderFirst = new ArrayList<String>();}
    this.orderFirst.set(index, item); return (A)this;
  }
  public A addToOrderFirst(java.lang.String... items) {
    if (this.orderFirst == null) {this.orderFirst = new ArrayList<String>();}
    for (String item : items) {this.orderFirst.add(item);} return (A)this;
  }
  public A addAllToOrderFirst(Collection<String> items) {
    if (this.orderFirst == null) {this.orderFirst = new ArrayList<String>();}
    for (String item : items) {this.orderFirst.add(item);} return (A)this;
  }
  public A removeFromOrderFirst(java.lang.String... items) {
    for (String item : items) {if (this.orderFirst!= null){ this.orderFirst.remove(item);}} return (A)this;
  }
  public A removeAllFromOrderFirst(Collection<String> items) {
    for (String item : items) {if (this.orderFirst!= null){ this.orderFirst.remove(item);}} return (A)this;
  }
  public List<String> getOrderFirst() {
    return this.orderFirst;
  }
  public String getOrderFirst(Integer index) {
    return this.orderFirst.get(index);
  }
  public String getFirstOrderFirst() {
    return this.orderFirst.get(0);
  }
  public String getLastOrderFirst() {
    return this.orderFirst.get(orderFirst.size() - 1);
  }
  public String getMatchingOrderFirst(Predicate<String> predicate) {
    for (String item: orderFirst) { if(predicate.test(item)){ return item;} } return null;
  }
  public Boolean hasMatchingOrderFirst(Predicate<String> predicate) {
    for (String item: orderFirst) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withOrderFirst(List<String> orderFirst) {
    if (orderFirst != null) {this.orderFirst = new ArrayList(); for (String item : orderFirst){this.addToOrderFirst(item);}} else { this.orderFirst = null;} return (A) this;
  }
  public A withOrderFirst(java.lang.String... orderFirst) {
    if (this.orderFirst != null) {this.orderFirst.clear();}
    if (orderFirst != null) {for (String item :orderFirst){ this.addToOrderFirst(item);}} return (A) this;
  }
  public Boolean hasOrderFirst() {
    return orderFirst != null && !orderFirst.isEmpty();
  }
  public A addToOrderLast(Integer index,String item) {
    if (this.orderLast == null) {this.orderLast = new ArrayList<String>();}
    this.orderLast.add(index, item);
    return (A)this;
  }
  public A setToOrderLast(Integer index,String item) {
    if (this.orderLast == null) {this.orderLast = new ArrayList<String>();}
    this.orderLast.set(index, item); return (A)this;
  }
  public A addToOrderLast(java.lang.String... items) {
    if (this.orderLast == null) {this.orderLast = new ArrayList<String>();}
    for (String item : items) {this.orderLast.add(item);} return (A)this;
  }
  public A addAllToOrderLast(Collection<String> items) {
    if (this.orderLast == null) {this.orderLast = new ArrayList<String>();}
    for (String item : items) {this.orderLast.add(item);} return (A)this;
  }
  public A removeFromOrderLast(java.lang.String... items) {
    for (String item : items) {if (this.orderLast!= null){ this.orderLast.remove(item);}} return (A)this;
  }
  public A removeAllFromOrderLast(Collection<String> items) {
    for (String item : items) {if (this.orderLast!= null){ this.orderLast.remove(item);}} return (A)this;
  }
  public List<String> getOrderLast() {
    return this.orderLast;
  }
  public String getOrderLast(Integer index) {
    return this.orderLast.get(index);
  }
  public String getFirstOrderLast() {
    return this.orderLast.get(0);
  }
  public String getLastOrderLast() {
    return this.orderLast.get(orderLast.size() - 1);
  }
  public String getMatchingOrderLast(Predicate<String> predicate) {
    for (String item: orderLast) { if(predicate.test(item)){ return item;} } return null;
  }
  public Boolean hasMatchingOrderLast(Predicate<String> predicate) {
    for (String item: orderLast) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withOrderLast(List<String> orderLast) {
    if (orderLast != null) {this.orderLast = new ArrayList(); for (String item : orderLast){this.addToOrderLast(item);}} else { this.orderLast = null;} return (A) this;
  }
  public A withOrderLast(java.lang.String... orderLast) {
    if (this.orderLast != null) {this.orderLast.clear();}
    if (orderLast != null) {for (String item :orderLast){ this.addToOrderLast(item);}} return (A) this;
  }
  public Boolean hasOrderLast() {
    return orderLast != null && !orderLast.isEmpty();
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    LegacySortOptionsFluentImpl that = (LegacySortOptionsFluentImpl) o;
    if (orderFirst != null ? !orderFirst.equals(that.orderFirst) :that.orderFirst != null) return false;
    if (orderLast != null ? !orderLast.equals(that.orderLast) :that.orderLast != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(orderFirst,  orderLast,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (orderFirst != null && !orderFirst.isEmpty()) { sb.append("orderFirst:"); sb.append(orderFirst + ","); }
    if (orderLast != null && !orderLast.isEmpty()) { sb.append("orderLast:"); sb.append(orderLast + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> kubernetes-model-kustomize-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/LegacySortOptionsFluentImpl.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import java.lang.SuppressWarnings;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LegacySortOptionsFluentImpl<A extends LegacySortOptionsFluent<A>> extends BaseFluent<A> implements LegacySortOptionsFluent<A>{
  public LegacySortOptionsFluentImpl() {
  }
  public LegacySortOptionsFluentImpl(LegacySortOptions instance) {
    if (instance != null) {
      this.withOrderFirst(instance.getOrderFirst());
      this.withOrderLast(instance.getOrderLast());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private List<String> orderFirst = new ArrayList<String>();
  private List<String> orderLast = new ArrayList<String>();
  private Map<String,Object> additionalProperties;
  public A addToOrderFirst(int index,String item) {
    if (this.orderFirst == null) {this.orderFirst = new ArrayList<String>();}
    this.orderFirst.add(index, item);
    return (A)this;
  }
  public A setToOrderFirst(int index,String item) {
    if (this.orderFirst == null) {this.orderFirst = new ArrayList<String>();}
    this.orderFirst.set(index, item); return (A)this;
  }
  public A addToOrderFirst(java.lang.String... items) {
    if (this.orderFirst == null) {this.orderFirst = new ArrayList<String>();}
    for (String item : items) {this.orderFirst.add(item);} return (A)this;
  }
  public A addAllToOrderFirst(Collection<String> items) {
    if (this.orderFirst == null) {this.orderFirst = new ArrayList<String>();}
    for (String item : items) {this.orderFirst.add(item);} return (A)this;
  }
  public A removeFromOrderFirst(java.lang.String... items) {
    for (String item : items) {if (this.orderFirst!= null){ this.orderFirst.remove(item);}} return (A)this;
  }
  public A removeAllFromOrderFirst(Collection<String> items) {
    for (String item : items) {if (this.orderFirst!= null){ this.orderFirst.remove(item);}} return (A)this;
  }
  public List<String> getOrderFirst() {
    return this.orderFirst;
  }
  public String getOrderFirst(int index) {
    return this.orderFirst.get(index);
  }
  public String getFirstOrderFirst() {
    return this.orderFirst.get(0);
  }
  public String getLastOrderFirst() {
    return this.orderFirst.get(orderFirst.size() - 1);
  }
  public String getMatchingOrderFirst(Predicate<String> predicate) {
    for (String item: orderFirst) { if(predicate.test(item)){ return item;} } return null;
  }
  public Boolean hasMatchingOrderFirst(Predicate<String> predicate) {
    for (String item: orderFirst) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withOrderFirst(List<String> orderFirst) {
    if (orderFirst != null) {this.orderFirst = new ArrayList(); for (String item : orderFirst){this.addToOrderFirst(item);}} else { this.orderFirst = null;} return (A) this;
  }
  public A withOrderFirst(java.lang.String... orderFirst) {
    if (this.orderFirst != null) {this.orderFirst.clear(); _visitables.remove("orderFirst"); }
    if (orderFirst != null) {for (String item :orderFirst){ this.addToOrderFirst(item);}} return (A) this;
  }
  public Boolean hasOrderFirst() {
    return orderFirst != null && !orderFirst.isEmpty();
  }
  public A addToOrderLast(int index,String item) {
    if (this.orderLast == null) {this.orderLast = new ArrayList<String>();}
    this.orderLast.add(index, item);
    return (A)this;
  }
  public A setToOrderLast(int index,String item) {
    if (this.orderLast == null) {this.orderLast = new ArrayList<String>();}
    this.orderLast.set(index, item); return (A)this;
  }
  public A addToOrderLast(java.lang.String... items) {
    if (this.orderLast == null) {this.orderLast = new ArrayList<String>();}
    for (String item : items) {this.orderLast.add(item);} return (A)this;
  }
  public A addAllToOrderLast(Collection<String> items) {
    if (this.orderLast == null) {this.orderLast = new ArrayList<String>();}
    for (String item : items) {this.orderLast.add(item);} return (A)this;
  }
  public A removeFromOrderLast(java.lang.String... items) {
    for (String item : items) {if (this.orderLast!= null){ this.orderLast.remove(item);}} return (A)this;
  }
  public A removeAllFromOrderLast(Collection<String> items) {
    for (String item : items) {if (this.orderLast!= null){ this.orderLast.remove(item);}} return (A)this;
  }
  public List<String> getOrderLast() {
    return this.orderLast;
  }
  public String getOrderLast(int index) {
    return this.orderLast.get(index);
  }
  public String getFirstOrderLast() {
    return this.orderLast.get(0);
  }
  public String getLastOrderLast() {
    return this.orderLast.get(orderLast.size() - 1);
  }
  public String getMatchingOrderLast(Predicate<String> predicate) {
    for (String item: orderLast) { if(predicate.test(item)){ return item;} } return null;
  }
  public Boolean hasMatchingOrderLast(Predicate<String> predicate) {
    for (String item: orderLast) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withOrderLast(List<String> orderLast) {
    if (orderLast != null) {this.orderLast = new ArrayList(); for (String item : orderLast){this.addToOrderLast(item);}} else { this.orderLast = null;} return (A) this;
  }
  public A withOrderLast(java.lang.String... orderLast) {
    if (this.orderLast != null) {this.orderLast.clear(); _visitables.remove("orderLast"); }
    if (orderLast != null) {for (String item :orderLast){ this.addToOrderLast(item);}} return (A) this;
  }
  public Boolean hasOrderLast() {
    return orderLast != null && !orderLast.isEmpty();
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LegacySortOptionsFluentImpl that = (LegacySortOptionsFluentImpl) o;
    if (!java.util.Objects.equals(orderFirst, that.orderFirst)) return false;

    if (!java.util.Objects.equals(orderLast, that.orderLast)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(orderFirst,  orderLast,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (orderFirst != null && !orderFirst.isEmpty()) { sb.append("orderFirst:"); sb.append(orderFirst + ","); }
    if (orderLast != null && !orderLast.isEmpty()) { sb.append("orderLast:"); sb.append(orderLast + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}
